@@ -138,7 +138,8 @@ typedef struct {
 typedef enum {
     READ_METADATA = 1,
     READ_IMAGE = 2,
-    READ_ALL = 3
+    READ_ALL = 3,
+    READ_ANY = 5        // Don't abort on non-jpeg files.
 }ReadMode_t;
 
 
